@@ -208,16 +208,6 @@ void AppletPrivate::setDestroyed(bool destroyed)
         for (Applet *a : lstApplets) {
             a->d->setDestroyed(destroyed);
         }
-    } else {
-        const auto children = q->children();
-        for (QObject *child : children) {
-            // Some non-containment applets can have another applet as child to
-            // emulate nested containments, such as the systray and grouping plasmoid
-            Plasma::Applet *applet = qobject_cast<Plasma::Applet *>(child);
-            if (applet) {
-                applet->d->setDestroyed(destroyed);
-            }
-        }
     }
     Q_EMIT q->configNeedsSaving();
 }
@@ -350,14 +340,12 @@ QMap<QString, QAction *> AppletPrivate::defaultActions(QObject *parent)
     configAction->setAutoRepeat(false);
     configAction->setText(i18n("Widget Settings"));
     configAction->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
-    configAction->setShortcut(QKeySequence(QStringLiteral("alt+d, s")));
 
     QAction *closeApplet = new QAction(parent);
     actions[QStringLiteral("remove")] = closeApplet;
     closeApplet->setAutoRepeat(false);
     closeApplet->setText(i18n("Remove this Widget"));
     closeApplet->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
-    closeApplet->setShortcut(QKeySequence(QStringLiteral("alt+d, r")));
 
     return actions;
 }
@@ -366,12 +354,14 @@ void AppletPrivate::contextualActions_append(QQmlListProperty<QAction> *prop, QA
 {
     Applet *a = static_cast<Plasma::Applet *>(prop->object);
     a->d->contextualActions.append(action);
-    QObject::connect(action, &QObject::destroyed, a, [a, action]() {
-        if (a->destroyed())
-            return;
-        a->d->contextualActions.removeAll(action);
-        Q_EMIT a->contextualActionsChanged(a->d->contextualActions);
-    });
+    if (action) { // some operations like inserting in the middle may append nullptr
+        QObject::connect(action, &QObject::destroyed, a, [a, action]() {
+            if (a->destroyed())
+                return;
+            a->d->contextualActions.removeAll(action);
+            Q_EMIT a->contextualActionsChanged(a->d->contextualActions);
+        });
+    }
     Q_EMIT a->contextualActionsChanged(a->d->contextualActions);
 };
 
@@ -414,8 +404,13 @@ void AppletPrivate::contextualActions_removeLast(QQmlListProperty<QAction> *prop
 
 void AppletPrivate::requestConfiguration()
 {
-    if (q->containment()) {
-        Q_EMIT q->containment()->configureRequested(q);
+    Plasma::Containment *cont = q->containment();
+    // Containments can be arbitrarly nested, so find the top-most one which is in the view directly
+    while (cont && cont->containment() != cont) {
+        cont = cont->containment();
+    }
+    if (cont) {
+        Q_EMIT cont->configureRequested(q);
     }
 }
 
@@ -430,12 +425,18 @@ void AppletPrivate::propagateConfigChanged()
 
 void AppletPrivate::setUiReady()
 {
-    // am i the containment?
-    Containment *c = qobject_cast<Containment *>(q);
-    if (c && c->isContainment()) {
-        c->d->setUiReady();
-    } else if (Containment *cc = q->containment()) {
-        cc->d->appletLoaded(q);
+    // If we a re a containment, call setUiReady
+    Containment *thisContainment = qobject_cast<Containment *>(q);
+    if (thisContainment && thisContainment->isContainment()) {
+        thisContainment->d->setUiReady();
+    }
+
+    // If we are inside a containment, call appletLoaded on the containment
+    // Note that q->containment() might be a different containment
+    // also for a containment as is possible to have nested containments, such as the systemtray
+    Containment *parentContainment = q->containment();
+    if (parentContainment && parentContainment != thisContainment) {
+        parentContainment->d->appletLoaded(q);
     }
 }
 
@@ -487,7 +488,7 @@ KConfigGroup *AppletPrivate::mainConfigGroup()
         parentApplet = qobject_cast<Plasma::Applet *>(c->parent());
     }
 
-    if (q->isContainment()) {
+    if (q->isContainment() && static_cast<Containment *>(q)->containmentType() != Containment::CustomEmbedded) {
         Corona *corona = static_cast<Containment *>(q)->corona();
         KConfigGroup containmentConfig;
         // qCDebug(LOG_PLASMA) << "got a corona, baby?" << (QObject*)corona << (QObject*)q;
